CoreTypography class
Core Typography class that defines text styles for the application
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bodyLargeMedium(
{Color? color}) → TextStyle -
bodyLargeRegular(
{Color? color}) → TextStyle -
bodyLargeSemiBold(
{Color? color}) → TextStyle -
bodyMediumMedium(
{Color? color}) → TextStyle -
bodyMediumRegular(
{Color? color}) → TextStyle -
bodyMediumSemiBold(
{Color? color}) → TextStyle -
bodySmallMedium(
{Color? color}) → TextStyle -
bodySmallRegular(
{Color? color}) → TextStyle -
bodySmallSemiBold(
{Color? color}) → TextStyle -
headlineLargeRegular(
{Color? color}) → TextStyle -
headlineLargeSemiBold(
{Color? color}) → TextStyle -
headlineMediumRegular(
{Color? color}) → TextStyle -
headlineMediumSemiBold(
{Color? color}) → TextStyle -
titleLargeMedium(
{Color? color}) → TextStyle -
titleLargeRegular(
{Color? color}) → TextStyle -
titleLargeSemiBold(
{Color? color}) → TextStyle -
titleMediumMedium(
{Color? color}) → TextStyle -
titleMediumRegular(
{Color? color}) → TextStyle -
titleMediumSemiBold(
{Color? color}) → TextStyle
Constants
- medium → const FontWeight
- regular → const FontWeight
- semiBold → const FontWeight