A chip component specifically designed for calculator or input-driven
interfaces. It displays a value and an optional label, supporting
interactive, disabled, and active states.
A selectable chip that supports three sizes, an optional leading icon,
a persistent close (×) button, and animated visual feedback for default,
pressed, and selected states.
Core icon widget that supports both Material and SVG icons
icon is the icon data to be displayed
size is the size of the icon
color is the color of the icon
semanticLabel is the semantic label for the icon
onTap is the callback function when the icon is tapped
padding is the padding around the icon
A widget that displays a letter avatar PNG based on the first letter of a name.
name is the name used to determine which letter avatar to display.
The letter avatar is determined by the first letter of the name (A-Z).
semanticLabel is an optional semantic label for accessibility.
A custom text field widget with optional label, helper text, and error text
label The label text displayed above the text field
helperText The helper text displayed below the text field
hintText The hint text displayed inside the text field
errorTextList The list of error messages displayed below the text field
errorWidgetList The list of error widgets displayed below the text field
obscureText Whether or not the text should be obscured
controller The controller for the text field
onChanged The callback function called when the text field value changes
keyboardType The keyboard type for the text field
enabled Whether or not the text field is enabled
validator The validator function for the text field
focusNode The focus node for the text field
initialValue The initial value for the text field
readOnly Whether or not the text field is read-only
prefix The widget displayed before the text field
suffix The widget displayed after the text field
isPhoneNumber Whether or not the text field is used for phone number input
phonePrefix The phone number prefix to display
onPhonePrefixChanged The callback function called when the phone prefix changes
phonePrefixes The list of available phone number prefixes
countryCodePickerTitle The title for the country code picker dialog
Used to show a toast message to the user.
It provides a static interface to easily display a toast message conveniently.
It has the following methods:
showError shows an error toast.
showSuccess shows a success toast.
showWarning shows a warning toast.
showCustomToast shows a custom toast.
example: