CoreSpacing class
Core Spacing class that defines spacing values for the application
The spacing system is based on a 4px grid (0.25rem with 16px base) Each value is named by its multiplier of the base unit @see https://www.figma.com/design/vugaGpii5HfgEQHPbrS3mU/Construculator-Visual-Design?node-id=7-2716&t=zZdz9haSNp4XklEm-4
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- space1 → const double
- space2 → const double
- space3 → const double
- space4 → const double
- space5 → const double
- space6 → const double
- space7 → const double
- space8 → const double
- space9 → const double
- space10 → const double
- space12 → const double
- space14 → const double
- space16 → const double
- space20 → const double
- space24 → const double
- space32 → const double
- space40 → const double
- space48 → const double
- space56 → const double
- space57 → const double
- space64 → const double