SuccessModal class
A modal that shows a success message and a button to continue.
message is the message to show.
isDismissible is whether the modal is dismissible.
enableDrag is whether the modal can be dragged.
onPressed is the callback to call when the button is pressed.
buttonLabel is the label of the button.
assetPath is the path to the asset to show.
Example:
SuccessModal.show(
context,
message: 'Operation Successful',
onPressed: () {
Navigator.pop(context);
},
);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {String? message, bool isDismissible = false, bool enableDrag = false, required VoidCallback onPressed, required String buttonLabel}) → void